import { matchPath } from "react-router";

// Mock the CCCE API
export function mockAPI() {
  // api spec
  cy.intercept("**/ccce-api", { fixture: "ccce-api.json" }).as("ccceAPI");

  // authentication
  cy.intercept("POST", "**/authentication/login", login).as("login");
  cy.intercept("GET", "**/authentication/roles", auth(roles)).as("userRoles");
  cy.intercept("POST", "**/authentication/renew", auth(renew)).as("renew")

  // ioc
  cy.intercept("GET", /.*\/iocs\/\d+/, getIOC).as("getIOC");

  // git
  cy.intercept("GET", "**/gitHelper/userInfo", auth(userInfo)).as("userInfo");

  // deployments
  cy.intercept("GET", /.*\/deployments\/\d+/, getDeployment).as("getDeployment")
  cy.intercept("GET", /.*\/deployments\/jobs\/\d+/, getDeploymentJob).as("getDeploymentJob")
  cy.intercept("GET", /.*\/deployments\/jobs\/\d+\/log/, auth(getDeploymentJobLog)).as("getDeploymentJobLog")
  
  // commands
  cy.intercept("GET", /.*\/deployments\/commands/, getCommandList).as("getCommandList")

  // hosts
  cy.intercept("GET", /.*\/hosts\/with-status\/\d+/, getCSEntryHostWithStatus).as("getCSEntryHostWithStatus")

  // monitoring
  cy.intercept("GET", /.*\/monitoring\/procserv\/host\/.+/, auth(getProcservLogs)).as("getProcservLogs")
}

function getParameters(req, pattern) {
  const match = matchPath(new URL(req.url).pathname, {
    path: "/api/v1" + pattern,
    exact: true,
    strict: false
  });
  return match?.params;
}

function login(req) {
  const token = "DEADBEEF";
  req.reply({
    headers: {
      "Set-Cookie": `ccce-auth=${token};`
    },
    body: {
      token,
    },
  })
}

function isLoggedIn(req) {
  return (req.headers?.cookie ?? "").includes("ccce-auth=");
}

function auth(routeHandler) {
  return function(req) {
    if (isLoggedIn(req)) {
      routeHandler(req);
    }
    else {
      req.reply({
        statusCode: 401
      })
    }
  }
}

function roles(req) {
  req.reply(["DeploymentToolAdmin", "DeploymentToolIntegrator"]);
}

function userInfo(req) {
  req.reply({
    "fullName": "John Wayne",
    "loginName": "johnwayne",
    "avatar": "https://gitlab.esss.lu.se/uploads/-/system/user/avatar/92/avatar.png",
    "email": null
  });
}

function renew(req) {
  req.reply({token: "FADEDEAD"});
}

function getIOC(req) {
  const params = getParameters(req, "/iocs/:id")
  const data = require("../fixtures/IOCDetails.json")
  const d = data.find(x => x.id === parseInt(params.id));
  const response = d ? d : {statusCode: 404};
  req.reply(response);
}

function getDeployment(req) {
  const params = getParameters(req, "/deployments/:id")
  const data = require("../fixtures/DeploymentInfoDetails.json");
  const d = data.find(x => x.id === parseInt(params.id));
  const response = d ? d : {statusCode: 404};
  req.reply(response);
}

function getDeploymentJob(req) {
  const params = getParameters(req, "/deployments/jobs/:id");
  const data = require("../fixtures/AwxJobDetails.json");
  const d = data.find(x => x.id === parseInt(params.id));
  const response = d ? d : {statusCode: 404};
  req.reply(response);
}

function getDeploymentJobLog(req) {
  const params = getParameters(req, "/deployments/jobs/:id/log");
  const jobDetailsData = require("../fixtures/AwxJobDetails.json");
  const index = jobDetailsData.findIndex(x => x.id === parseInt(params.id))
  const logData = require("../fixtures/AwxJobLog.json");
  const d = logData[index];
  const response = d ? d : {statusCode: 404};
  req.reply(response);
}

function getCommandList(req) {
  const data = require("../fixtures/PagedCommandResponse.json");
  req.reply(data);
}

function getCSEntryHostWithStatus(req) {
  const params = getParameters(req, "/hosts/with-status/:id")
  const data = require("../fixtures/CSEntryHostWithStatus.json");
  const d = data.find(x => x.csEntryHost.id === parseInt(params.id));
  const response = d ? d : {statusCode: 404};
  req.reply(response);
}

function getProcservLogs(req) {
  const data = require("../fixtures/LokiResponse.json");
  req.reply(data);
}

