import React, { useState, useRef, useEffect } from 'react';
import { useHistory } from "react-router-dom";
import { makeStyles } from '@material-ui/core/styles';
import { Button, Typography, Grid, Tooltip } from "@material-ui/core";
import { theme } from "../../style/Theme";
import { useUndeployInDb } from '../../api/SwaggerApi';
import { SimpleAccordion } from "../common/Accordion/SimpleAccordion";
import { ConfirmationDialog } from "../dialog/ConfirmationDialog";
import { SimpleModal } from "../../components/common/SimpleModal/SimpleModal";
import { Alert } from "@material-ui/lab";
import AccessControl from '../auth/AccessControl';

const useStyles = makeStyles({
    undeployButton: {
        backgroundColor: '#aa2e25',
        color: '#FFFFFF',
        "&:disabled": {
            backgroundColor: '#e0e0e0',
            color: '#afaba6',
        },
        "&:hover": {
            backgroundColor: '#6c0000',
            color: '#FFFFFF',
        }
    },
});

export default function AdministerUndeployment({ ioc, buttonDisabled }) {

    const classes = useStyles(theme);

    const history = useHistory();

    function onError(message) {
        setError(message);
    }  

    //for the dialog
    const [error, setError] = useState();
    const [adHocDialogOpen, setAdHocDialogOpen] = useState(false);
    const [adHocDialogTitle, setAdHocDiatlogTitle] = useState();
    const [adHocDialogDescription, setAdHocDialogDescription] = useState();
    const callbackRef = useRef();

    const [response, undeployIOC] = useUndeployInDb(ioc.id, onError);

    //Setting up dialog properties
    const openUndeployModal = () => {
        setAdHocDiatlogTitle("Administratively 'undeploy' IOC");
        setAdHocDialogDescription(
            <>
                <Typography style={{ display: 'inline-block' }}>Are you sure want to administer IOC as undeployed &nbsp;</Typography>
                <Typography style={{ fontFamily: "monospace", display: 'inline-block' }}> {ioc.namingName}? </Typography>
            </>);
        callbackRef.current = undeployIoc;
        setAdHocDialogOpen(true);
    }

    //what to do when "undeploying" the IOC
    const undeployIoc = async () => {
        undeployIOC();
    }

    useEffect(() => 
    {
      if (response) {
        history.goBack();
      }
    }, [response, history]);

    let iocIsDeployed = ioc.activeDeployment && !ioc.activeDeployment.undeployment;

    let disabledButtonTitle = "";
    if (buttonDisabled || ioc.operationInProgress) {
        disabledButtonTitle = "There is an ongoing operation, you cannot 'undeploy' the IOC right now";
    } else {
        if (!iocIsDeployed) {
            disabledButtonTitle = "IOC is not deployed, you cannot 'undeploy' it"
        }
    }

    return (
        <>
            <AccessControl allowedRoles={["DeploymentToolAdmin"]}
                renderNoAccess={() =>
                    <></>
                }>
                <>
                    <SimpleModal open={adHocDialogOpen} setOpen={setAdHocDialogOpen}>
                        <ConfirmationDialog open={adHocDialogOpen} setOpen={setAdHocDialogOpen} title={adHocDialogTitle} description={adHocDialogDescription} callback={callbackRef.current} />
                    </SimpleModal>

                    <SimpleAccordion summary="Change deployment status to not deployed (e.g. if IOC has been manually removed)" defaultExpanded>
                        <Grid container spacing={1}>
                            {error ?
                                <Grid item xs={12}>
                                    <Alert severity="error">{error}</Alert>
                                </Grid>
                                : <></>}
                            <Grid item xs={12}>
                                <Tooltip title={disabledButtonTitle}>
                                    <span>
                                        <Button className={classes.undeployButton} onClick={openUndeployModal} disabled={buttonDisabled || ioc.operationInProgress || !iocIsDeployed} >SET DEPLOYMENT STATE TO NOT DEPLOYED</Button>
                                    </span>
                                </Tooltip>
                            </Grid>
                        </Grid>
                    </SimpleAccordion>
                </>
            </AccessControl>
        </>
    )
}