import React, { useState, useRef, useEffect } from 'react';
import { useHistory } from "react-router-dom";
import { makeStyles } from '@material-ui/core/styles';
import { Button, Typography, Grid, Tooltip } from "@material-ui/core";
import { theme } from "../../style/Theme";
import { useDeleteIOC } from '../../api/SwaggerApi';
import { SimpleAccordion } from "../common/Accordion/SimpleAccordion";
import { ConfirmationDialog } from "../dialog/ConfirmationDialog";
import { SimpleModal } from "../../components/common/SimpleModal/SimpleModal";
import { Alert } from "@material-ui/lab";

const useStyles = makeStyles({
    deleteButton: {
        backgroundColor: '#aa2e25',
        color: '#FFFFFF',
        "&:disabled": {
            backgroundColor: '#e0e0e0',
            color: '#afaba6',
        },
        "&:hover": {
            backgroundColor: '#6c0000',
            color: '#FFFFFF',
        }
    },
});

export default function IOCDelete({ ioc, buttonDisabled }) {
    const classes = useStyles(theme);

    const history = useHistory();

    function onError(message) {
        setError(message);
    }  

    //for the dialog
    const [error, setError] = useState();
    const [adHocDialogOpen, setAdHocDialogOpen] = useState(false);
    const [adHocDialogTitle, setAdHocDiatlogTitle] = useState();
    const [adHocDialogDescription, setAdHocDialogDescription] = useState();
    const callbackRef = useRef();

    const [response, deleteIOC] = useDeleteIOC(ioc.id, onError);

    //Setting up dialog properties
    const openDeleteModal = () => {
        setAdHocDiatlogTitle("Deleting IOC");
        setAdHocDialogDescription(
            <>
                <Typography style={{ display: 'inline-block' }}>Are you sure want to delete &nbsp;</Typography>
                <Typography style={{ fontFamily: "monospace", display: 'inline-block' }}> {ioc.namingName}? </Typography>
            </>);
        callbackRef.current = deleteIoc;
        setAdHocDialogOpen(true);
    }

    //what to do when deleting IOC
    const deleteIoc = async () => {
        deleteIOC();
    }

    useEffect(() => 
    {
      if (response) {
        history.goBack();
      }
    }, [response, history]);

    let disabledButtonTitle = "";
    if (buttonDisabled || ioc.operationInProgress) {
        disabledButtonTitle = "There is an ongoing operation, you can not delete the IOC right now";
    }


    return (
        <>
            <SimpleModal open={adHocDialogOpen} setOpen={setAdHocDialogOpen}>
                <ConfirmationDialog open={adHocDialogOpen} setOpen={setAdHocDialogOpen} title={adHocDialogTitle} description={adHocDialogDescription} callback={callbackRef.current} />
            </SimpleModal>

            <SimpleAccordion summary="Delete IOC" defaultExpanded>
                <Grid container spacing={1}>
                    {error ?
                    <Grid item xs={12}>
                        <Alert severity="error">{error}</Alert>
                    </Grid>
                    : <></>}
                    <Grid item xs={12}>
                        <Tooltip title={disabledButtonTitle}>
                            <span>
                                <Button className={classes.deleteButton} onClick={openDeleteModal} disabled={buttonDisabled || ioc.operationInProgress } >Delete IOC</Button>
                            </span>
                        </Tooltip>
                    </Grid>
                </Grid>
            </SimpleAccordion>
        </>
    );
}