import React, { useCallback, useContext, useEffect } from "react";
import { Typography } from "@material-ui/core";
import { SimpleAccordion } from "../common/Accordion/SimpleAccordion";
import { IOCDetails } from "./IOCDetails";
import { Link } from 'react-router-dom';
import { LokiContainer } from "../common/Loki/LokiContainer";
import { Alert } from '@material-ui/lab';
import GitRefLink from "./GitRefLink";
import AlertMessages from "./AlertMessages";
import { IOCService } from "./IOCService";
import { IOCCommandTable } from "./IOCCommandTable";
import AccessControl from '../../components/auth/AccessControl';
import { useDeploymentJobById, userContext } from "../../api/SwaggerApi";
import { DeploymentStatus } from "../../api/DataTypes";

export function IOCLiveStatus({ ioc, currentCommand, commands, getCommands, buttonDisabled, setButtonDisabled,
  commandLazyParams, setCommandLazyParams, commandColumnSort, setCommandColumnSort, rowsPerPage }) {
  const { user } = useContext(userContext);
  const [deploymentJob, getDeploymentJobById] = useDeploymentJobById();

  useEffect(() => {
    if (ioc.activeDeployment?.awxJobId) {
      getDeploymentJobById(ioc.activeDeployment?.awxJobId);
    }
  }, [getDeploymentJobById, ioc.activeDeployment?.awxJobId]) 

  const liveIOC = { ...ioc };
  liveIOC.name = ioc.namingName;

  const getSubset = useCallback((ioc) => {
    //Show START/STOP components only when IOC was deployed SUCCESSFULLY
    const deploymentStatus = new DeploymentStatus(ioc.activeDeployment, deploymentJob);
    const showControls = deploymentStatus.wasSuccessful();
    let subset = {
      "Git reference": <GitRefLink ioc={ioc} />,
      "Description": ioc.description,
      "Owner": ioc.owner,
      "Deployed on":
        <Typography>
          {ioc.activeDeployment?.host.csEntryId ?
            <Link to={`/hosts/${ioc.activeDeployment?.host.csEntryId}`}>{ioc.activeDeployment?.host.fqdn}</Link>
            :
            <>{ioc.activeDeployment?.host.fqdn}</>
          }
        </Typography>,
    }
    if (user) {
      subset["IOC Service Controls"] = showControls ?
        <IOCService {...{ioc, currentCommand, getCommands, buttonDisabled, setButtonDisabled, commandColumnSort, commandLazyParams}} /> 
        : "Can't be controlled, because IOC is not (yet) deployed succesfully";
    }

    return subset
  }, [buttonDisabled, commandColumnSort, commandLazyParams, currentCommand, deploymentJob, getCommands, setButtonDisabled, user]);

  function isIocDeployed(ioc) {
    return Boolean(ioc.activeDeployment);
  }

  return (
    <>
      <IOCDetails ioc={liveIOC} getSubset={getSubset} alert={<AlertMessages alerts={liveIOC.alerts} />} />
      <SimpleAccordion summary="IOC Service Control log">
        <IOCCommandTable commands={commands}
          commandLazyParams={commandLazyParams} setCommandLazyParams={setCommandLazyParams} commandColumnSort={commandColumnSort} setCommandColumnSort={setCommandColumnSort}
          rowsPerPage={rowsPerPage} />
      </SimpleAccordion>
      <AccessControl allowedRoles={["DeploymentToolAdmin", "DeploymentToolIntegrator"]}
        renderNoAccess={() => <></>}>
        <SimpleAccordion summary="ProcServLog info" defaultExpanded>
          {liveIOC.activeDeployment?.host.csEntryId ?
            <LokiContainer csEntryId={liveIOC.activeDeployment?.host.csEntryId} iocName={ioc.namingName} isDeployed={isIocDeployed(ioc)} />
            :
            <Alert severity="error" variant="standard">Invalid CSentry ID for target host</Alert>
          }
        </SimpleAccordion>
      </AccessControl>
    </>
  );
}
