import React, { useEffect, useState } from "react";
import { useCommandList, useIOC } from "../../api/SwaggerApi";
import { mountIntoHarness } from "../../mocks/AppHarness";
import { initRequestParams } from "../common/Helper";
import { IOCLiveStatus } from "./IOCLiveStatus";

function IOCLiveStatusContainer() {
  const [ioc] = useIOC(2);
  const [commands, getCommands] = useCommandList();
  const [commandParams, setCommandParams] = useState({ first: 0, rows: 5, page: 0 });
  const [columnSort, setColumnSort] = useState({ sortField: null, sortOrder: null });
  const [rowsPerPage] = useState([5, 10, 20, 50]);
  const [buttonDisabled, setButtonDisabled] = useState(false);

  useEffect(() => {
    if (ioc) {
      let requestParams = initRequestParams(commandParams, null, columnSort);
      requestParams.deploymentId = ioc.activeDeployment?.id;
      getCommands(requestParams);
    }
  }, [getCommands, ioc, commandParams, columnSort])

  return ioc ?
    <IOCLiveStatus
      ioc={ioc}
      currentCommand={null}
      commands={commands}
      getCommands={getCommands}
      buttonDisabled={buttonDisabled}
      setButtonDisabled={setButtonDisabled}
      commandLazyParams={commandParams}
      setCommandLazyParams={setCommandParams}
      commandColumnSort={columnSort}
      setCommandColumnSort={setColumnSort}
      rowsPerPage={rowsPerPage}
    />
    : null;
}

function commonTests() {
  cy.wait("@getCommandList");

  // Expect IOC name in badge
  cy.contains("CCCE:SC-IOC-001");

  // Expected in Info table:
  cy.contains("ee3ae2a8b9e7e83e4eb511eee340716e9d541056") // git reference
  cy.contains("Test IOC for CCCE") // description
  cy.contains("johnsparger") // owner
  cy.contains("ccce-w40.cslab.esss.lu.se") // deployed on

  // Expected in service control log
  cy.contains("IOC Service Control log").click()
  cy.get('.ccce-custom-table svg[title="Successful"]')
  cy.get('.ccce-custom-table svg[title="Start IOC"]')
}

describe("IOCLiveStatus", () => {
  context("when not logged in", () => {
    it("displays the common components", () => {
      mountIntoHarness(<IOCLiveStatusContainer />)
      commonTests();
    })
  })

  context("when logged in", () => {
    beforeEach(() => {
      cy.login();
      mountIntoHarness(<IOCLiveStatusContainer />);
    })

    it("displays the logged in view", () => {
      commonTests();
      // check for IOC service controls
      cy.get("button").contains("stop", { matchCase: false })
      // check for procserv logs
      cy.wait("@getProcservLogs");
      cy.contains("This is some fake log data");
    })
  })
})