import { mount } from "@cypress/react";
import { SnackbarProvider } from "notistack";
import React from "react";
import { APIProvider, UserProvider } from "../../api/SwaggerApi";
import TokenRenew from "./TokenRenew";

function AppHarness({ children }) {
  return (
    <SnackbarProvider preventDuplicate maxSnack="5">
      <APIProvider>
        <UserProvider>
          {children}
        </UserProvider>
      </APIProvider>
    </SnackbarProvider>
  )
}

function mountIntoHarness(children) {
  mount(<AppHarness>{children}</AppHarness>)
}

describe("TokenRenew", () => {
  context("when logged in", () => {
    beforeEach(() => {
      cy.login();
    })

    it("renews the token periodically", () => {
      cy.clock();
      mountIntoHarness(<TokenRenew />);
      cy.tick(window.TOKEN_RENEW_INTERVAL);
      cy.wait("@renew", {responseTimeout: 1000})
    })
  })
})