import React, { useState, useCallback } from 'react';
import { LinearProgress, Typography, Container } from '@material-ui/core';
import { useDeploymentJobLogById } from '../../api/SwaggerApi';
import { Console } from "../common/Console/Console";
import { Alert } from "@material-ui/lab";
import { useSafePolling } from '../../hooks/Polling';

const LOG_POLL_INTERVAL = 5000;
export function DeploymentJobOutput({ deploymentJob }) {
  const [error] = useState();

  // function onError(message) {
  //   setError(message);
  // }  

  const [log, getLogById, /*reset*/, logLoading] = useDeploymentJobLogById();
  const getLog = useCallback(() => {
    getLogById(deploymentJob.id);
  },
    // eslint warns here, 
    // but we actually do want the log to update every time the deploymentJob updates
    [deploymentJob, deploymentJob.id, getLogById]
  )
  useSafePolling(getLog, logLoading, LOG_POLL_INTERVAL)

  const dataReady = useCallback(() => {
    return deploymentJob?.started;
  }, [deploymentJob?.started])

  let header = (
    <div style={{
      display: "flex",
      alignItems: "center"
    }}>
      <Typography variant="overline">DURATION: </Typography>
      <Typography style={{
        marginLeft: "6px",
      }}>
        {log?.elapsed.toFixed(0)} s
      </Typography>
    </div>
  );

  return (
    <Container maxWidth='xl'>
      {error ?
        <Alert severity="error">{error}</Alert>
        :
        log ?
          <div style={{
            width: "100%",
          }}>
            <Console
              html={log.stdoutHtml}
              dataReady={dataReady}
              title="AWX job details"
              dialogHeader={header}
            />
          </div>
          :
          <div style={{ width: "100%" }}><LinearProgress color="primary" /></div>
      }
    </Container>
  )
}