import React from 'react';
import { CustomTable } from "../common/table/CustomTable";
import { Grid, Tooltip } from "@material-ui/core";
import { DeploymentStatusIcon, DeploymentTypeIcon } from './DeploymentIcons';
import { useHistory } from 'react-router';
import { formatDate } from '../common/Helper';

const formatDeploymentDate = (value) => {
    if (value) {
      return formatDate(value);
    }
    return "Not started yet";
}

const dateTemplate = (rowData) => {
    return formatDeploymentDate(rowData.start);
}

const columns = [
  { id: 'type', label: 'Type', width: '5%'},
  { id: 'ioc', label: 'IOC Name', width: '16%', sortable: true },
  { id: 'host', label: 'Host', width: '15%', sortable: false },
  { id: 'network', label: 'Network', width: '22%', sortable: false },
  { id: 'user', label: 'User', width: '12%', sortable: true },
  { id: 'version', label: 'Git reference', width: '15%', sortable: true },
  { id: 'start', label: 'Start date', width: '15%', body: dateTemplate, sortable: true }
];

function createGitVersionField(version, shortVersion) {
  return(
    <Tooltip title={version} arrow enterDelay={400}>
              <label>{shortVersion ?? version}</label>
    </Tooltip>
  )
}

function createTableRow(deployment) {
  return { 
    id:deployment.id,
    type:
      <Grid container direction="column" justifyContent="center" alignItems="center">
        <DeploymentTypeIcon type={deployment.undeployment ? "undeploy" : "deploy"}/>
      </Grid>,
    status: 
      <Grid container direction="column" justifyContent="center" alignItems="center">
        <DeploymentStatusIcon status={deployment.status}/>
      </Grid>,
    ioc: deployment.namingName,
    version: createGitVersionField(deployment.sourceVersion, deployment.sourceVersionShort), 
    host: deployment.host?.hostName ?? null,
    network: deployment.host?.network ?? null, 
    user: deployment.createdBy,
    start: deployment.startDate,
    deploymentFailed: deployment.status === 'FAILED'
  };
}

export function DeploymentsTable({deployments, totalCount, lazyParams, setLazyParams, columnSort, setColumnSort, rowsPerPage, loading}) {
  const history = useHistory();

  const onRowClicked = (id) => {
    history.push(`/deployments/${id}`);
  };

  return (
    <CustomTable columns={columns} rows={deployments.map(deployment => createTableRow(deployment))} handleRowClick={onRowClicked}
      totalCount={totalCount} lazyParams={lazyParams} setLazyParams={setLazyParams} columnSort={columnSort} setColumnSort={setColumnSort} 
      rowsPerPage={rowsPerPage} loading={loading}/>
  );
}