import React from "react";
import { mount } from "@cypress/react";
import { SnackbarProvider } from "notistack";
import { ThemeProvider } from "@material-ui/core";
import { BrowserRouter as Router } from "react-router-dom";
import { theme } from "../style/Theme";
import { APIProvider, UserProvider } from "../api/SwaggerApi";
import { NotificationProvider } from "../components/common/notification/Notifications";
import { GlobalAppBar } from "../components/navigation/GlobalAppBar/GlobalAppBar";

export function AppHarness({ children }) {
  return (
    <SnackbarProvider preventDuplicate maxSnack="5">
      <ThemeProvider theme={theme}>
        <Router>
          <APIProvider>
            <UserProvider>
              <NotificationProvider>
                <GlobalAppBar>
                  {children}
                </GlobalAppBar>
              </NotificationProvider>
            </UserProvider>
          </APIProvider>
        </Router>
      </ThemeProvider>
    </SnackbarProvider>
  )
}

export function mountIntoHarness(children) {
  mount(<AppHarness>{children}</AppHarness>)
}