import { Grid, Paper, Tab, Tabs, Typography, IconButton } from "@material-ui/core";
import ArrowBackIcon from '@material-ui/icons/ArrowBack';
import React, { useCallback, useEffect, useState } from "react";
import { useCommandList, useOngoingCommand } from "../../api/SwaggerApi";
import { IOCLiveStatus } from "../../components/IOC/IOCLiveStatus";
import { IOCManage } from "../../components/IOC/IOCManage";
import { useHistory } from "react-router-dom";
import IOCAdmin from "../../components/IOC/IOCAdmin";
import AccessControl from "../../components/auth/AccessControl";
import { initRequestParams } from "../../components/common/Helper";
import { useGlobalAppBar } from '../../components/navigation/GlobalAppBar/GlobalAppBar';
import { useSafePolling } from "../../hooks/Polling";

const IOC_POLL_INTERVAL = 10000;
export function IOCDetailsView({ ioc, getIOC, loading }) {
  console.log(ioc);
  const [selectedTab, setSelectedTab] = useState("Status");
  const [firstTime, setFirstTime] = useState(true);
  const [buttonDisabled, setButtonDisabled] = useState(false);
  const history = useHistory();
  const [commands, getCommands] = useCommandList();
  const [ongoingCommand, getOngoingCommand, /*reset*/, ongoingCommandLoading] = useOngoingCommand(ioc.id);

  const [commandLazyParams, setCommandLazyParams] = useState({
    first: 0,
    rows: 5,
    page: 0
  });

  const [commandColumnSort, setCommandColumnSort] = useState({
    sortField: null,
    sortOrder: null
  });

  const rowsPerPage = [5, 10, 20, 50];

  useSafePolling(getIOC, loading, IOC_POLL_INTERVAL);
  useSafePolling(getOngoingCommand, ongoingCommandLoading, IOC_POLL_INTERVAL);

  useEffect(() => {
    setButtonDisabled(Boolean(ioc?.operationInProgress));
  }, [ioc?.operationInProgress]);

  const handleTabChange = (event, tab) => {
    setSelectedTab(tab);
  };

  useEffect(() => {
    if (firstTime && ioc && ioc.activeDeployment) {
      setSelectedTab("Status");
      setFirstTime(false);
    }
  }, [ioc, firstTime]);

  useEffect(() => {
    let requestParams = initRequestParams(commandLazyParams, null, commandColumnSort);

    requestParams.deploymentId = ioc.activeDeployment?.id;

    getCommands(requestParams);

  }, [getCommands, commandLazyParams, commandColumnSort, ioc])

  const handleClick = () => {
    history.goBack();
  };

  const resetTab = useCallback( () => {
    if (ioc?.activeDeployment) {
      setSelectedTab("Status");
    } else {
      setSelectedTab("Manage deployment");
    }
  }, [ioc?.activeDeployment])

  const setButtonDisabledAndUpdate = useCallback((isDisabled) => {
    setButtonDisabled(isDisabled);
    getIOC();
  }, [getIOC])

  const { setTitle } = useGlobalAppBar("IOC Details");

  useEffect(() => {
    ioc && setTitle("IOC Details: " + ioc.namingName);
  }, [ioc, setTitle]);

  const noAccessTabs = [
    <Tab key="Status" label={<Typography variant="h5">Status</Typography>} value="Status" />,
  ]

  const adminTabs = [
    ...noAccessTabs,
    <Tab key="Manage deployment" label={<Typography variant="h5">Manage deployment</Typography>} value="Manage deployment" />,
    <Tab key="IOC Admin" label={<Typography variant="h5">IOC Admin</Typography>} value="IOC Admin" />
  ]

  const CustomTabs = ({ children }) => {
    return (
      <Tabs
        value={selectedTab}
        onChange={handleTabChange}
        indicatorColor="primary"
        textColor="primary"
      >
        {children}
      </Tabs>
    );
  }

  return (
    <Paper>
      <Grid container spacing={1}>
        <Grid item xs={1}>
          <IconButton color="inherit" onClick={handleClick}>
            <ArrowBackIcon />
          </IconButton>
        </Grid>
        <Grid item xs={11}>
          <Grid container justify="center">
            <AccessControl
              allowedRoles={["DeploymentToolAdmin"]}
              allowedUsersWithRoles={[{ user: ioc.owner, role: "DeploymentToolIntegrator" }]}
              renderNoAccess={() =>
                <CustomTabs>
                  {ioc && noAccessTabs}
                </CustomTabs>
              }>

              <CustomTabs>
                {ioc && adminTabs}
              </CustomTabs>
            </AccessControl>
          </Grid>
        </Grid>
        <Grid item xs={12} style={{ paddingBottom: 0 }}>
          {selectedTab === "Status" && <IOCLiveStatus ioc={ioc} currentCommand={ongoingCommand}
            commands={commands} getCommands={getCommands}
            buttonDisabled={buttonDisabled} setButtonDisabled={setButtonDisabledAndUpdate}
            commandLazyParams={commandLazyParams} setCommandLazyParams={setCommandLazyParams} commandColumnSort={commandColumnSort} setCommandColumnSort={setCommandColumnSort}
            rowsPerPage={rowsPerPage} />}
          {selectedTab === "Manage deployment" && <IOCManage ioc={ioc} getIOC={getIOC} buttonDisabled={buttonDisabled} />}
          {selectedTab === "IOC Admin" && <IOCAdmin ioc={ioc} getIOC={getIOC} resetTab={resetTab} buttonDisabled={buttonDisabled} />}
        </Grid>
      </Grid>
    </Paper>
  );
}