import React, { useCallback, useRef } from 'react';
import { DeploymentDetailsView } from "./DeploymentDetailsView";
import { LinearProgress } from '@material-ui/core';
import { useDeployment, useDeploymentJobById } from "../../api/SwaggerApi";
import { useSafePolling } from '../../hooks/Polling';
import { DeploymentStatus } from '../../api/DataTypes';

const POLL_DEPLOYMENT_INTERVAL = 5000;
export function DeploymentDetailsContainer({ id }) {
  console.log(id);
  const [deployment, getDeployment, /*reset*/, deploymentLoading] = useDeployment(id);
  const [deploymentJob, getDeploymentJobById, /*reset*/, deploymentJobLoading] = useDeploymentJobById();
  const firstTime = useRef(true);

  const deploymentStatus = new DeploymentStatus(deployment, deploymentJob);
  const deploymentFinished = deploymentStatus.isFinished();

  const getDeploymentUntilFinished = useCallback(() => {
    if (!deploymentFinished) {
      getDeployment();
    }
  }, [deploymentFinished, getDeployment])

  const getDeploymentJobUntilFinished = useCallback(() => {
    if (!deploymentFinished || firstTime.current) {
      if (deployment?.awxJobId) {
        getDeploymentJobById(deployment.awxJobId)
        firstTime.current = false;
      }
    }
  }, [deployment?.awxJobId, deploymentFinished, getDeploymentJobById])

  return (
    <>
      {deployment ?
        <DeploymentDetailsView deployment={deployment} deploymentJob={deploymentJob} />
        :
        <LinearProgress color="primary" />
      }
      <Watcher get={getDeploymentUntilFinished} loading={deploymentLoading} />
      {deployment?.awxJobId && <Watcher get={getDeploymentJobUntilFinished} loading={deploymentJobLoading} />}
    </>
  );
}

function Watcher({ get, loading }) {
  useSafePolling(get, loading, POLL_DEPLOYMENT_INTERVAL)
  return null;
}