import { Container, Grid, Paper, Button, Box, Typography } from "@material-ui/core";
import React, { useState} from "react";
import { useGlobalAppBar } from "../../components/navigation/GlobalAppBar/GlobalAppBar";
import { CreateIOC } from "../../components/IOC/CreateIOC";
import { KeyValueTable } from "../../components/common/KeyValueTable/KeyValueTable";
import { SimpleModal } from "../../components/common/SimpleModal/SimpleModal";
import { IOCAsyncList } from "../../components/IOC/IOCAsyncList";
import { SimpleAccordion } from '../../components/common/Accordion/SimpleAccordion';
import { useCreateIOC, useAnnouncements, usePersonalStatistics, useOwnIocsWithAlarms } from "../../api/SwaggerApi";
import ReactMarkdown from 'react-markdown'
import { makeStyles } from '@material-ui/core/styles';

const useStyles = makeStyles((theme) => ({
  root: {
    marginBottom: theme.spacing(2),
  },
  announcements: {
    paddingLeft: theme.spacing(3),
    paddingRight: theme.spacing(3),
  }
}));

export function HomeView() {
  const [iocFormOpen, setIOCFormOpen] = useState(false);
  const [announcements] = useAnnouncements();
  const [statistics] = usePersonalStatistics();
  const [iocsWithAlarms, /*getIocsWithAlarms*/, /*resetResponse*/, loading] = useOwnIocsWithAlarms();
  const classes = useStyles();

  const [lazyParams, setLazyParams] = useState({
    first: 0,
    rows: 100,
    page: 0
  });

  const [columnSort, setColumnSort] = useState({
    sortField: null,
    sortOrder: null
  });

  console.log("rendering Own IOCs")

  useGlobalAppBar("Home");

  const closeModal = () => {
    setIOCFormOpen(false);
  }  

  return (
    <Container>
      <Paper className={classes.root}>
          <Grid container spacing={1} justify="flex-end">
            <Grid item xs={10}>
              <Box display="flex" flexDirection="row" p={2} m={1}>
              <Typography variant="h2">
                My statistics
              </Typography>
              </Box>
            </Grid>
            <Grid item xs={2}>
              <Box display="flex" flexDirection="row-reverse" p={2} m={1}>
                <Button variant="contained" color="secondary" onClick={() => { setIOCFormOpen(true) }}>New IOC</Button>
              </Box>
            </Grid>
            {statistics &&
            <Grid item xs={12}>
              <KeyValueTable obj={{"Total number of my IOCs": statistics.numberOfActiveIocs}} variant="table" />
            </Grid>
            }
            <Grid item xs={12}>
              <SimpleAccordion summary="My IOCs with alarms" defaultExpanded>
                    <IOCAsyncList iocs={iocsWithAlarms} asyncDetails={false} rowType="own" loading={loading}
                      lazyParams={lazyParams} setLazyParams={setLazyParams} 
                      columnSort={columnSort} setColumnSort={setColumnSort}
                      totalCount={iocsWithAlarms?.length}
                      paginator={false} />
              </SimpleAccordion>
            </Grid>
          </Grid>
          {announcements?.announcementsText &&
          <Grid container justify="flex-start" className={classes.announcements}>
            <Grid item xs={12}>
                <ReactMarkdown>
                  {announcements.announcementsText}
                </ReactMarkdown>
            </Grid>
          </Grid>
          }
          <SimpleModal open={iocFormOpen} setOpen={setIOCFormOpen}>
            <CreateIOC open={iocFormOpen} setOpen={setIOCFormOpen} isUpdateIoc={false} submitCallback={closeModal} hook={useCreateIOC} title="Create new IOC" buttonText="Create"/>
          </SimpleModal>
      </Paper>
    </Container>
  );
}

